@@ -133,37 +133,37 @@ class Payments(Resource):
                 #         }
                 #     })
 
-                # if 'reference' in payload.keys():
-                #     data.update({
-                #         "PaymentRefNum": payload.get("reference", "")
-                #     })
+                if 'reference' in payload.keys():
+                    data.update({
+                        "PaymentRefNum": payload.get("reference", "")
+                    })
                 
-                # invoices = payload.get("invoice_payments", [])
+                invoices = payload.get("invoice_payments", [])
 
-                # for i in range(len(invoices)):
-                #     invoice = {}
-                #     if 'amount' in invoices[i].keys():
-                #         invoice.update({
-                #             "Amount": invoices[i].get("amount", "")
-                #         })
+                for i in range(len(invoices)):
+                    invoice = {}
+                    if 'amount' in invoices[i].keys():
+                        invoice.update({
+                            "Amount": int(invoices[i].get("amount", 0))
+                        })
 
-                #     if 'invoice_id' in invoices[i].keys():
-                #         invoice.update({
-                #             "LinkedTxn": [
-                #                 {
-                #                     "TxnId": invoices[i].get('invoice_id',""),
-                #                     "TxnType": "Invoice"
-                #                 }
-                #             ]
-                #         })
+                    if 'invoice_id' in invoices[i].keys():
+                        invoice.update({
+                            "LinkedTxn": [
+                                {
+                                    "TxnId": invoices[i].get('invoice_id',""),
+                                    "TxnType": "Invoice"
+                                }
+                            ]
+                        })
                     
-                #     invoices[i] = invoice
+                    invoices[i] = invoice
 
-                # # if invoices has data in it
-                # if bool(invoices):
-                #     data.update({
-                #         "Line": invoices
-                #     })
+                # if invoices has data in it
+                if bool(invoices):
+                    data.update({
+                        "Line": invoices
+                    })
 
             # If client type is ZOHO
             elif super().get_client_type() == super().ZOHO:
@@ -179,7 +179,7 @@ class Payments(Resource):
 
                 if 'amount' in payload.keys():
                     payment.update({
-                        "amount": payload.get("amount", "")
+                        "amount": f'{payload.get("amount", "0")}'
                     })
 
                 if 'reference' in payload.keys():
@@ -297,8 +297,7 @@ class Payments(Resource):
                         invoice_payments[i]['Account'] = invoice_payments[i].pop(
                             'account_id')
                     if 'amount' in invoice_payments[i].keys():
-                        invoice_payments[i]['Amount'] = invoice_payments[i].pop(
-                            'amount')
+                        invoice_payments[i]['Amount'] = int(invoice_payments[i].pop('amount'))
 
                 # if invoice_payments has data in it
                 if bool(invoice_payments):
@@ -326,7 +325,7 @@ class Payments(Resource):
 
                 if 'amount' in payload.keys():
                     payment.update({
-                        "Amount": payload.get("amount", "")
+                        "Amount": int(payload.get("amount", 0))
                     })
 
                 if 'reference' in payload.keys():
@@ -340,14 +339,16 @@ class Payments(Resource):
                             "AccountID": payload.get("account_id", "")
                         }
                     })
+                
+                invoice = payload.get("invoice_payments", [])
 
-                if 'invoice_id' in payload.keys():
-                    payment.update({
-                        "Invoice": {
-                            "InvoiceID": payload.get("invoice_id", ""),
-                            "LineItems": payload.get("invoice_payments", []),
-                        }
-                    })
+                if bool(invoice):
+                    if "invoice_id" in invoice[0].keys():
+                        payment.update({
+                            "Invoice": {
+                                "InvoiceID": f'{invoice[0].pop("invoice_id")}',
+                            }
+                        }) 
 
                 if bool(payment):
                     data.update({
@@ -359,11 +360,28 @@ class Payments(Resource):
                 data = {
                     "partner_type": "customer",
                     "date": payload.get("date", ""),
-                    "amount": payload.get("amount", 0),
-                    "partner_id": payload.get("customer_id", ""),
+                    "amount": int(payload.get("amount", 0)),
+                    "partner_id": int(payload.get("customer_id", 0)),
                     "payment_reference": payload.get("reference", ""),
                 }
 
+                invoices = payload.get("invoice_payments", [])
+
+                for i in range(len(invoices)):
+                    if "invoice_id" in invoices[i].keys():
+                        invoices[i]["invoice_id"] = invoices[i].pop("invoice_id")
+                    if "amount" in invoices[i].keys():
+                        invoices[i]["amount"] = int(invoices[i].pop("amount"))
+                    
+                    invoices[i].pop("payment_date")
+                    invoices[i].pop("payment_reference")
+                    invoices[i].pop("payment_type")
+                    invoices[i].pop("account_id")
+
+                # if line_items has data in it
+                if bool(invoices):
+                    data.update({"invoices": invoices})
+
             # If client type is MS_DYNAMICS
             elif super().get_client_type() == super().MS_DYNAMICS:
                 data.pop("type")
